@@ -6,7 +6,7 @@ use warnings;
 
 use base 'Test::Builder::Module';
 
-our $VERSION = '0.42';
+our $VERSION = '0.43';
 our $AUTHORITY = 'cpan:JJNAPIORK';
 
 use Config::Any;
@@ -63,7 +63,7 @@ sub import {
                     }
 
                     if($search) {
-                        my @search = ref $search ? @$search : ($search, @_);
+                        my @search = ref $search eq 'ARRAY' ? @$search : ($search, @_);
                         $resultset = $resultset->search(@search);
                     }
 
@@ -722,7 +722,7 @@ assuming you put all of your test configuration in the standard place, your
     done_testing;
 
 Then, assuming the existence of a L<DBIx::Class::Schema> subclass called,
-"MyApp::Schema" and some L<DBIx::Class::ResultSources> named like "Person", 
+"MyApp::Schema" and some L<DBIx::Class::ResultSource>s named like "Person",
 "Person::Employee", "Job" and "Phone", will automatically deploy a testing 
 schema in the given database / storage (or auto deploy to an in-memory based
 L<DBD::SQLite> database), install fixtures and let you run some test cases, 
@@ -845,6 +845,9 @@ normal methods against it.
 
 This is the same as the test above.
 
+ResultSet can also be called with a C<< $source, [\%search,
+\%condition] >> signature.
+
 =head2 fixtures_ok
 
 This is used to install and verify installation of fixtures, either inlined,
@@ -1146,7 +1149,7 @@ against a temporary instance of MySQL. For this trait MySQL and L<DBD::mysql>
 needs to be installed, but MySQL does not need to be running, nor do you need
 to create a test database or user.   The third one is the 
 L<Test::DBIx::Class::SchemaManager::Trait::Testpostgresql> trait, which is
-built on top of L<Test::postgresql> and allows you to deploy to and run tests
+built on top of L<Test::PostgreSQL> and allows you to deploy to and run tests
 against a temporary instance of Postgresql.  For this trait Postgresql
 and L<DBD::Pg> needs to be installed, but Postgresql does not need to be
 running, nor do you need to create a test database or user.  
@@ -1384,14 +1387,10 @@ directory.
 
 =head1 TRAITS
 
-As described, a trait is a L<Moose::Role> that is applied to the class managing
-your database and test instance.  Currently we only have the default 'SQLite'
-trait and the 'Testmysqld' trait, but we eventually intend to have traits to
-add easy support for creating Postgresql databases and supporting testing on
-replicated systems.
-
-Traits are installed by the 'traits' configuration option, which expects an
-ArrayRef as its input (however will also normalize a scalar to an ArrayRef).
+As described, a trait is a L<Moose::Role> that is applied to the class
+managing your database and test instance.  Traits are installed by the
+'traits' configuration option, which expects an ArrayRef as its input
+(however will also normalize a scalar to an ArrayRef).
 
 Available traits are as follows.
 
