@@ -13,7 +13,16 @@ package Test::DBIx::Class::FixtureCommand::Populate; {
 		$builder->croak("Argument is required.")
 		  unless $arg;
 
-		my @args = (ref $arg && ref $arg eq 'ARRAY') ? @$arg : ($arg, @rest);
+		my @args;
+		if(ref $arg && ref $arg eq 'ARRAY') {
+			@args = @$arg;
+		}
+		elsif(ref $arg && ref $arg eq 'HASH') {
+			@args = %$arg;
+		}
+		else {
+			@args = ($arg, @rest);
+		}
 
 		my @definitions;
 		while(@args) {
@@ -29,21 +38,10 @@ package Test::DBIx::Class::FixtureCommand::Populate; {
 		my @return;
 		foreach my $definition (@definitions) {
 			my ($source, $rows) = each %$definition;
+            my $rs = $self->schema_manager->schema->resultset($source);
 
-			$builder->ok(
-			  my $rs = $self->schema_manager->schema->resultset($source), 
-			  "Got ResultSet for $source"
-			);
-			my @rows;
-			eval {
-				@rows =  $rs->populate($rows);
-			};
-
-			if($@) {
-				Test::More::fail("Can't install fixtures for $source, got $@");
-			} else {
-				push @return, {$source => [@rows]};
-			}
+			my @rows =  $rs->populate($rows);
+			push @return, {$source => [@rows]};
 		}
 		return @return;
 	}
